==> haskell-yaml-0.8.28-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.8.28
id: yaml-0.8.28-1eKoxsWes94BHiHNW2BZN3
key: yaml-0.8.28-1eKoxsWes94BHiHNW2BZN3
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/snoyberg/yaml/
synopsis: Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>
category: Web
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
exposed: True
indefinite: False
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Parser Data.Yaml.Pretty Data.Yaml.TH
    Text.Libyaml
hidden-modules: Data.Yaml.Internal
abi: 287e35d92ad4ba66ea87bbf2fe44e896
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yaml-0.8.28
library-dirs: /usr/lib/ghc-8.2.2/site-local/yaml-0.8.28
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/yaml-0.8.28
hs-libraries: HSyaml-0.8.28-1eKoxsWes94BHiHNW2BZN3
depends:
    base-4.10.1.0 transformers-0.5.2.0 bytestring-0.10.8.2
    conduit-1.2.13-CDuZ28lGSu78a4713mMJ0U
    resourcet-1.1.11-mPI1cqUz3aG4xWjbFZjoo
    aeson-1.2.4.0-CTZGfBqMyO6AGhBfx14U8h containers-0.5.10.2
    unordered-containers-0.2.9.0-GlwZSbNHLsw5b3PDCuUikn
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    attoparsec-0.13.2.2-ImfqXHsnQ0kLjIvcUXLfco
    scientific-0.3.5.2-KEYSfvoh38pANFLUbcUMJR filepath-1.4.1.2
    directory-1.3.0.2 semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             conduit-1.2.13-CDuZ28lGSu78a4713mMJ0U=caeb25cfddba8a8d9ec474fb262978cb
             resourcet-1.1.11-mPI1cqUz3aG4xWjbFZjoo=af01948f1b6a617c3a6af518771ef52e
             aeson-1.2.4.0-CTZGfBqMyO6AGhBfx14U8h=8c49f5b853f3a7be5ef595f7dce8b68a
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             unordered-containers-0.2.9.0-GlwZSbNHLsw5b3PDCuUikn=e523ad11a5c5a0977b92d6afb6220c8b
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             attoparsec-0.13.2.2-ImfqXHsnQ0kLjIvcUXLfco=02dde2665ea78b3a3aa2c59359e39730
             scientific-0.3.5.2-KEYSfvoh38pANFLUbcUMJR=41eaba84bf55b69834d982565e00c1d4
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=c739600aa012ae17eb506df1a043419b
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.8.28-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.8.28
id: yaml-0.8.28-KGmAlvbQggcBIRUCjbx1A8
key: yaml-0.8.28-KGmAlvbQggcBIRUCjbx1A8
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/snoyberg/yaml/
synopsis: Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>
category: Web
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
exposed: True
indefinite: False
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Parser Data.Yaml.Pretty Data.Yaml.TH
    Text.Libyaml
hidden-modules: Data.Yaml.Internal
abi: 5e8c92c4f0f4251a1b70e4c32a1c389d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yaml-0.8.28
library-dirs: /usr/lib/ghc-8.2.2/site-local/yaml-0.8.28
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/yaml-0.8.28
hs-libraries: HSyaml-0.8.28-KGmAlvbQggcBIRUCjbx1A8
depends:
    base-4.10.1.0 transformers-0.5.2.0 bytestring-0.10.8.2
    conduit-1.2.13-CDuZ28lGSu78a4713mMJ0U
    resourcet-1.1.11-mPI1cqUz3aG4xWjbFZjoo
    aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU containers-0.5.10.2
    unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj
    scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG filepath-1.4.1.2
    directory-1.3.0.2 semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             conduit-1.2.13-CDuZ28lGSu78a4713mMJ0U=caeb25cfddba8a8d9ec474fb262978cb
             resourcet-1.1.11-mPI1cqUz3aG4xWjbFZjoo=af01948f1b6a617c3a6af518771ef52e
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz=9d795026e0df763f1ffeaf92b7adcdda
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj=9d8982f8b70cf41a2e1b007eb9382565
             scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG=490d099f5e386f4f486a599d7d1e6789
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=c739600aa012ae17eb506df1a043419b
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
